Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSergey Sharybin <sergey.vfx@gmail.com>2015-05-20 14:59:28 +0300
committerSergey Sharybin <sergey.vfx@gmail.com>2015-05-20 21:10:07 +0300
commit148ed4e05eafd3642d7f8f16f7c28a2267bcf4b8 (patch)
treed2e6b5708e001a360db10b67e5ad5861be4cae18 /intern/cycles/kernel
parent6f48df45ee2ea0dcead4eb3b9df78191e8047a0e (diff)
Cycles: Cleanup, synchronize name across file name, program and kernel names
Diffstat (limited to 'intern/cycles/kernel')
-rw-r--r--intern/cycles/kernel/kernel_data_init.cl2
-rw-r--r--intern/cycles/kernel/kernel_next_iteration_setup.cl4
-rw-r--r--intern/cycles/kernel/kernel_shader_eval.cl22
-rw-r--r--intern/cycles/kernel/kernel_shadow_blocked.cl2
4 files changed, 15 insertions, 15 deletions
diff --git a/intern/cycles/kernel/kernel_data_init.cl b/intern/cycles/kernel/kernel_data_init.cl
index 4c5f08639dd..62b5c4e6a29 100644
--- a/intern/cycles/kernel/kernel_data_init.cl
+++ b/intern/cycles/kernel/kernel_data_init.cl
@@ -51,7 +51,7 @@
* All slots in queues are initialized to queue empty slot;
* The number of elements in the queues is initialized to 0;
*/
-__kernel void kernel_ocl_path_trace_data_initialization(
+__kernel void kernel_ocl_path_trace_data_init(
ccl_global char *globals,
ccl_global char *shader_data_sd, /* Arguments related to ShaderData */
ccl_global char *shader_data_sd_DL_shadow, /* Arguments related to ShaderData */
diff --git a/intern/cycles/kernel/kernel_next_iteration_setup.cl b/intern/cycles/kernel/kernel_next_iteration_setup.cl
index 49562ca6ed5..3c0e4e9240d 100644
--- a/intern/cycles/kernel/kernel_next_iteration_setup.cl
+++ b/intern/cycles/kernel/kernel_next_iteration_setup.cl
@@ -27,7 +27,7 @@
*
* The input and output are as follows,
*
- * rng_coop ---------------------------------------------|--- kernel_ocl_path_trace_setup_next_iteration -|--- Queue_index (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
+ * rng_coop ---------------------------------------------|--- kernel_ocl_path_trace_next_iteration_setup -|--- Queue_index (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
* throughput_coop --------------------------------------| |--- Queue_data (QUEUE_HITBF_BUFF_UPDATE_TOREGEN_RAYS)
* PathRadiance_coop ------------------------------------| |--- throughput_coop
* PathState_coop ---------------------------------------| |--- PathRadiance_coop
@@ -61,7 +61,7 @@
* QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS will be filled with RAY_TO_REGENERATE and more RAY_UPDATE_BUFFER rays
*/
-__kernel void kernel_ocl_path_trace_setup_next_iteration(
+__kernel void kernel_ocl_path_trace_next_iteration_setup(
ccl_global char *globals,
ccl_constant KernelData *data,
ccl_global char *shader_data, /* Required for setting up ray for next iteration */
diff --git a/intern/cycles/kernel/kernel_shadow_blocked.cl b/intern/cycles/kernel/kernel_shadow_blocked.cl
index 72a2d0affb0..2fc4be6d528 100644
--- a/intern/cycles/kernel/kernel_shadow_blocked.cl
+++ b/intern/cycles/kernel/kernel_shadow_blocked.cl
@@ -47,7 +47,7 @@
* QUEUE_SHADOW_RAY_CAST_AO_RAYS and QUEUE_SHADOW_RAY_CAST_DL_RAYS will be empty at kernel exit.
*/
-__kernel void kernel_ocl_path_trace_shadow_blocked_direct_lighting(
+__kernel void kernel_ocl_path_trace_shadow_blocked(
ccl_global char *globals,
ccl_constant KernelData *data,
ccl_global char *shader_shadow, /* Required for shadow blocked */
diff --git a/intern/cycles/kernel/kernel_shader_eval.cl b/intern/cycles/kernel/kernel_shader_eval.cl
index 78cf19a3df8..b3983081be6 100644
--- a/intern/cycles/kernel/kernel_shader_eval.cl
+++ b/intern/cycles/kernel/kernel_shader_eval.cl
@@ -17,22 +17,22 @@
#include "kernel_split.h"
/*
* Note on kernel_ocl_path_trace_shader_evaluation kernel
* This kernel is the 5th kernel in the ray tracing logic. This is
* the 4rd kernel in path iteration. This kernel sets up the ShaderData
* structure from the values computed by the previous kernels. It also identifies
* the rays of state RAY_TO_REGENERATE and enqueues them in QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS queue.
*
* The input and output of the kernel is as follows,
- * rng_coop -------------------------------------------|--- kernel_ocl_path_trace_shader_evaluation --|--- shader_data
- * Ray_coop -------------------------------------------| |--- Queue_data (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
- * PathState_coop -------------------------------------| |--- Queue_index (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
- * Intersection_coop ----------------------------------| |
- * Queue_data (QUEUE_ACTIVE_AND_REGENERATD_RAYS)-------| |
- * Queue_index(QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)---| |
- * ray_state ------------------------------------------| |
- * kg (globals + data) --------------------------------| |
- * queuesize ------------------------------------------| |
+ * rng_coop -------------------------------------------|--- kernel_ocl_path_trace_shader_eval --|--- shader_data
+ * Ray_coop -------------------------------------------| |--- Queue_data (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
+ * PathState_coop -------------------------------------| |--- Queue_index (QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)
+ * Intersection_coop ----------------------------------| |
+ * Queue_data (QUEUE_ACTIVE_AND_REGENERATD_RAYS)-------| |
+ * Queue_index(QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS)---| |
+ * ray_state ------------------------------------------| |
+ * kg (globals + data) --------------------------------| |
+ * queuesize ------------------------------------------| |
*
* Note on Queues :
* This kernel reads from the QUEUE_ACTIVE_AND_REGENERATED_RAYS queue and processes
@@ -46,7 +46,7 @@
* QUEUE_HITBG_BUFF_UPDATE_TOREGEN_RAYS will be filled with RAY_TO_REGENERATE rays
*/
-__kernel void kernel_ocl_path_trace_shader_evaluation(
+__kernel void kernel_ocl_path_trace_shader_eval(
ccl_global char *globals,
ccl_constant KernelData *data,
ccl_global char *shader_data, /* Output ShaderData structure to be filled */
@@ -17,22 +17,22 @@
#include "kernel_split.h"
/*
- * Note on kernel_ocl_path_trace_shader_evaluation kernel
+ * Note on kernel_ocl_path_trace_shader_eval kernel
* This kernel is the 5th kernel in the ray tracing logic. This is
* the 4rd kernel in path iteration. This kernel sets up the ShaderData